Improve this Doc View Source

Specify custom behavior on paste event.

## Directive Info

- This directive executes at priority level 0.

## Usage

- as element:

      <ng-paste
        ng-paste="expression">
      ...
      </ng-paste>

- as attribute:

      <window, input, select, textarea, a
        ng-paste="expression">
      ...
      </window, input, select, textarea, a>

### Arguments

Param | Type | Details
--- | --- | ---
ngPaste | expression | Expression to evaluate upon paste. (Event object is available as `$event`)

## Examples

    <input ng-paste="paste=true" ng-init="paste=false" placeholder='paste here'>
    pasted: {{paste}}